@@ -88,7 +88,7 @@ def strat_daily(y, btc='BTC',tone=15,ttwo=26, p1=1., p2=1.05, long_expo=1., shor
             S[t] = short_expo
     return S
 
-def compute_daily_signal_lo(df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'],tone=15, ttwo=26, p1btc = 1.,p2btc = 1.05,p1eth = 1.,p2eth = 1.05,lo_sig_suffix='LO',compute_lo_strat=True, plot_html=False, whole_kpis = False, local_root_directory='none'):
+def compute_daily_signal_lo(df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'], exclude_core_token=False ,tone=15, ttwo=26, p1btc = 1.,p2btc = 1.05,p1eth = 1.,p2eth = 1.05,lo_sig_suffix='LO',compute_lo_strat=True, plot_html=False, whole_kpis = False, local_root_directory='none'):
     all_tokens = core_tokens + extra_tokens
 
     for me_token in all_tokens:
@@ -116,6 +116,10 @@ def compute_daily_signal_lo(df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['
         go_curate = lambda x: curate_signals(x, under=ssj)
         df[f'S{ssj}'] = df.apply(go_curate, axis=1)
 
+    if exclude_core_token:
+        for ssj in core_tokens:
+            df[f'S{ssj}'] = 0.
+
     signal_df = df.copy()
     signal_df = signal_df.fillna(0.)
     signal_df['Counter'] = 0
