@@ -176,7 +176,8 @@ def get_swapping_cost(swapping_size_proportion =None, swapping_cost_map=None):
         print(f'trouble computing swapping cost{percentage_swapping_size_proportion}')
         print(e)
     return cost
-def LS_IL_boundaries_with_signal(data_df = None, plotHtml = False, me_pair = ('ETH', 'BTC'), bb_periods=[5, 15, 30, 55], stdNbrs=[2., 3., 5.], distance_to_bound_percs = [0,5,10,15,20,30,40],current_apr_ethbtc=None, bypass_signal=True, bypass_stoploss=True, swapping_cost_map = {1:1e-4, 10:0.01, 50:0.05, 75:0.075, 100:0.1}):
+
+def LS_IL_boundaries_with_signal(data_df = None, plotHtml = False, me_pair = ('ETH', 'BTC'), bb_periods=[5, 15, 30, 55], stdNbrs=[2., 3., 5.], distance_to_bound_percs = [0,5,10,15,20,30,40], current_apr=None, bypass_signal=True, bypass_stoploss=True, swapping_cost_map = {1:1e-4, 10:0.01, 50:0.05, 75:0.075, 100:0.1}):
     ssj = me_pair[0]
     ssj_against = me_pair[1]
     objectives = []
@@ -238,7 +239,7 @@ def LS_IL_boundaries_with_signal(data_df = None, plotHtml = False, me_pair = ('E
                     flipped_lp_position_profit = np.nan
 
 
-                    apr = get_apr(row['DateStr'],  row['pct_change'], volume_df=data_df.copy(), current_apr_ethbtc=current_apr_ethbtc)
+                    apr = get_apr(row['DateStr'],  row['pct_change'], volume_df=data_df.copy(), current_apr=current_apr)
 
                     # if currently providing and we enter in a risk off mode we need to compute IL
                     we_are_out = np.isnan(real_upper_bound)
